@@ -501,13 +501,14 @@ static void
 gpk_task_setup_dialog_untrusted (GpkTask *task)
 {
 	GtkWidget *widget;
-	GtkWidget *button;
 	guint retval;
 	g_autoptr(GError) error = NULL;
 
 	/* get UI */
 	task->priv->builder_untrusted = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (task->priv->builder_untrusted, GPK_DATA "/gpk-error.ui", &error);
+	retval = gtk_builder_add_from_resource (task->priv->builder_untrusted,
+						"/org/gnome/packagekit/gpk-error.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 	}
@@ -527,17 +528,10 @@ gpk_task_setup_dialog_untrusted (GpkTask *task)
 	widget = GTK_WIDGET (gtk_builder_get_object (task->priv->builder_untrusted, "expander_details"));
 	gtk_widget_hide (widget);
 
-	/* TRANSLATORS: button label, force the install, even though it's untrusted */
-	button = gtk_button_new_with_mnemonic (_("_Force install"));
-	g_signal_connect (button, "clicked", G_CALLBACK (gpk_task_button_accept_cb), task);
-
-	/* TRANSLATORS: button tooltip */
-	gtk_widget_set_tooltip_text (button, _("Force installing package"));
-
 	/* add to dialog */
-	widget = GTK_WIDGET (gtk_builder_get_object (task->priv->builder_untrusted, "dialog_error"));
-	gtk_dialog_add_action_widget (GTK_DIALOG (widget), button, GTK_RESPONSE_NONE);
-	gtk_widget_show (button);
+	widget = GTK_WIDGET (gtk_builder_get_object (task->priv->builder_untrusted, "button_force"));
+	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_task_button_accept_cb), task);
+	gtk_widget_show (widget);
 }
 
 static void
@@ -549,7 +543,9 @@ gpk_task_setup_dialog_signature (GpkTask *task)
 
 	/* get UI */
 	task->priv->builder_signature = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (task->priv->builder_signature, GPK_DATA "/gpk-signature.ui", &error);
+	retval = gtk_builder_add_from_resource (task->priv->builder_signature,
+						"/org/gnome/packagekit/gpk-signature.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 	}
@@ -578,7 +574,9 @@ gpk_task_setup_dialog_eula (GpkTask *task)
 
 	/* get UI */
 	task->priv->builder_eula = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (task->priv->builder_eula, GPK_DATA "/gpk-eula.ui", &error);
+	retval = gtk_builder_add_from_resource (task->priv->builder_eula,
+						"/org/gnome/packagekit/gpk-eula.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 	}
